==> pure-www-18.5.3.zip: src/www/Dialvox/application/views/campanas/scripts/table.component.php <==
<div class="animated fadeInRight">
    <div class="col s12 card-panel white">
        <h4 id="Camptitle">{{traducirFrase("Campañas")}}</h4>
        <br>
        <div class="row">
            <div class="col s3">
                <input type='text' id='texto' class="form-control" v-bind:placeholder='traducirFrase("Busqueda")' onkeyup='pagina=1;cambiaPagina(pagina);'>
            </div>
        </div>
        <table class="table striped highlight responsive-table">
            <thead>
                <tr>
                    <th id="th1">{{traducirFrase("Id")}}</th>
                    <th id="th2">{{traducirFrase("Nombre")}}</th>
                    <th id="th3">{{traducirFrase("Grupo")}}</th>
                    <th id="th4">{{traducirFrase("Método de marcado")}}</th>
                    <th id="th5">{{traducirFrase("Nivel de marcado")}}</th>
                    <th id="th6">{{traducirFrase("Orden de registro")}}</th>
                    <th id="th7">{{traducirFrase("Opciones")}}</th>
                    <?php if ($_SESSION["Grupo"] == GRUPO_ADMINS) {?>
                        <th id="th8">{{traducirFrase("Activo")}}</th>
                    <?php }?>
                    <?php if ($_SESSION["Grupo"] == GRUPO_SUPERVISORES) {?>
                        <th id="th8">{{traducirFrase("Activo")}}</th>
                    <?php }?>
                </tr>
            </thead>
            <tbody>
                <tr v-for="dato in d.Campanas">
                    <td>{{dato.id}}</td>
                    <td>{{dato.nombre}}</td>
                    <td>{{dato.grupo}}</td>
                    <td v-if="dato.metodo==='MANUAL'">{{traducirFrase("SALIENTE - MANUAL")}}</td>
                    <td v-else-if="dato.metodo==='RATIO'">{{traducirFrase("PROGRESIVO")}}</td>
                    <td v-else-if="dato.metodo==='ADAPT_AVERAGE'">{{traducirFrase("PREDICTIVO PROMEDIO")}}</td>
                    <td v-else-if="dato.metodo==='ADAPT_HARD_LIMIT'">{{traducirFrase("PREDICTIVO ESTRICTO")}}</td>
                    <td v-else-if="dato.metodo==='ADAPT_TAPERED'">{{traducirFrase("PREDICTIVO TAPERED")}}</td>
                    <td v-else-if="dato.metodo==='INBOUND_MAN'">{{traducirFrase("ENTRADA - MANUAL")}}</td>
                    <td v-else>{{dato.metodo}}</td>
                    <td>{{dato.nivel}}</td>
                    <td>{{dato.orden}}</td>
                    <td>
                        <?php if ($_SESSION["Grupo"] == GRUPO_ADMINS) {?>
                            <a href="#" class="tooltipped" v-bind:data-tooltip="translate('Editar campaña')" data-position="top" v-on:click="abreModal2(dato.id,dato.idcampaign_wa)"><i class="material-icons">edit</i></a>
                            <a href="#" class="tooltipped" v-bind:data-tooltip="translate('Borrar campaña')" data-position="top" v-on:click="deleteCampana(dato.nombre,dato.id)"><i class="material-icons">delete</i></a>
                            <a href="#" class="tooltipped" v-bind:data-tooltip="translate('Duplicar campaña')" data-position="top" v-on:click="duplicarCampana(dato.nombre,dato.id)"><i class="material-icons">content_copy</i></a>
                        <?php }?>
                        <a class="tooltipped" v-bind:data-tooltip="translate('Estados de calificación')" data-position="top" href="#" v-on:click="abreModal3(dato.nombre,dato.id)"><i class="material-icons ">phone_missed</i></a>
                        <?php if ($_SESSION["Grupo"] == GRUPO_ADMINS) {?>
                            <a class="tooltipped" v-if="dato.campaign_allow_inbound == 'Y'" :data-tooltip="traducirFrase('Grupos de entrada')" data-position="top" href="#" @click="$emit('ingroups',dato)"><i class="material-icons ">play_for_work</i></a>
                            <!--  -->
                            <a class="tooltipped" :data-tooltip="traducirFrase('Agentes de la campaña')" data-position="top" href="#" @click="$emit('users',dato)"><i class="material-icons ">assignment_ind</i></a>
                            <!--  -->
                            <a class="tooltipped" :data-tooltip="traducirFrase('Grupos de transferencias')" data-position="top" href="#" @click="$emit('xfers',dato)"><i class="material-icons ">group_work</i></a>
                            <!--  -->
                            <?php if (isset($_SESSION["allowEncuestas"]) && $_SESSION["allowEncuestas"] == 1) {?>
                            <a class="tooltipped" :data-tooltip="traducirFrase('Encuestas')" data-position="top" href="#" @click="$emit('polls',dato)"><i class="material-icons ">poll</i></a>
                            <?php }?>
                        <?php }?>
                        <a class="tooltipped" :data-tooltip="traducirFrase('Estatus de reciclaje')" data-position="top" href="#" v-on:click="abreModal4(dato.nombre,dato.id)"><i class="material-icons ">autorenew</i></a>
                        <a class="tooltipped" v-bind:data-tooltip="translate('Codigos de Pausa')" data-position="top" href="#" v-on:click="abreModalPausa(dato.id)"><i href="#" class="material-icons">phone_paused</i></a>
                        <a class="tooltipped" :data-tooltip="translate('Ventanas de Agente')" data-position="top" href="#"  @click="abrirModalFrames(dato)"><i href="#" class="material-icons">tab</i></a>
                        <a href="#" @click.prevent="$emit('dates', dato.id)" class="tooltipped" v-bind:data-tooltip="translate('Descargar campaña')" data-position="top"><i class="material-icons">cloud_download</i></a>
                        <?php if (NEED_WA && $_SESSION['allow_waCli']) {?>
                            <a href="#" v-if="dato.haveWA==='1'" class="tooltipped modal-trigger" data-target="formuUp" :data-tooltip="traducirFrase('Subir registro a campaña (WhatsApp)')" data-position="top" v-bind:onclick="'idCampanaWAW=\`'+dato.idWA+'\`;'"><i class="material-icons">message</i></a>
                            <a href="#" v-if="dato.haveWA==='1'" class="tooltipped modal-trigger" data-target="formuCRM" :data-tooltip="traducirFrase('Mascara de datos (WhatsApp)')" data-position="top" v-bind:onclick="'idCampanaWAW=\`'+dato.idWA+'\`;'"><i class="material-icons">file_upload</i></a>
                            <a v-if="dato.haveWA==='1'" :href="'campanas/downloadCSVWhatsApp?campana='+dato.idWA" class="tooltipped" v-bind:data-tooltip="translate('Descargar reporte de mensajes enviados (WhatsApp)')" data-position="top"><i class="material-icons">cloud_download</i></a>
                            <a v-if="dato.haveWA==='1'" :href="'campanas/downloadFileWhatsApp?campana='+dato.idWA" class="tooltipped" v-bind:data-tooltip="translate('Descargar reporte de archivos (WhatsApp)')" data-position="top"><i class="material-icons">file_download</i></a>
                        <?php }?>


                    </td>
                    <?php if ($_SESSION["Grupo"] == GRUPO_ADMINS) {?>
                        <td>
                        <div class="switch">
                            <label class="active">
                                Off
                                <input type="checkbox" class="" v-on:click="activaCampana(dato.id)" :checked="dato.activo == 'Y'">
                                <span id="switch" class="lever  "></span>
                                On
                            </label>
                        </div>
                        </td>
                    <?php }?>

                    <?php if ($_SESSION["Grupo"] == GRUPO_SUPERVISORES) {?>
                        <td>
                        <div class="switch">
                            <label class="active">
                                Off
                                <input  disabled type="checkbox" class="" v-on:click="activaCampana(dato.id)" :checked="dato.activo == 'Y'">
                                <span id="switch" class="lever  "></span>
                                On
                            </label>
                        </div>
                        </td>
                    <?php }?>

                </tr>
            </tbody>
        </table>
        <div id="barrita">
            <center><img src="<?=IMG_ADMIN;?>spinner.gif"></center>
        </div>
        <br>
        <?php if ($_SESSION["Grupo"] == GRUPO_ADMINS) {?>
            <div class="center" id="botonCrear">
                <a class="waves-effect waves-light btn blue lighten-2 " href="javascript:abreModal()" id="Nueva Campaña">{{traducirFrase("Nueva campaña")}}</a>
            </div>
        <?php }?>
        <center><img src="<?=IMG_ADMIN;?>spinner.gif"  width="60" height="60" style="display: none; margin-top: 2rem;" id="spinnerPagination"></center>
        <ul class="pagination center" id='paginacion'>

        </ul>
    </div>
</div>

==> pure-www-18.5.21.zip: src/www/Dialvox/application/views/campanas/scripts/table.component.php <==
<div class="animated fadeInRight">
    <div class="col s12 card-panel white">
        <h4 id="Camptitle">{{traducirFrase("Campañas")}}</h4>
        <br>
        <div class="row">
            <div class="col s3">
                <input type='text' id='texto' class="form-control" v-bind:placeholder='traducirFrase("Busqueda")' onkeyup='pagina=1;cambiaPagina(pagina);'>
            </div>
        </div>
        <table class="table striped highlight responsive-table">
            <thead>
                <tr>
                    <th id="th1">{{traducirFrase("Id")}}</th>
                    <th id="th2">{{traducirFrase("Nombre")}}</th>
                    <th id="th3">{{traducirFrase("Grupo")}}</th>
                    <th id="th4">{{traducirFrase("Método de marcado")}}</th>
                    <th id="th5">{{traducirFrase("Nivel de marcado")}}</th>
                    <th id="th6">{{traducirFrase("Orden de registro")}}</th>
                    <th id="th7">{{traducirFrase("Opciones")}}</th>
                    <?php if ($_SESSION["Grupo"] == GRUPO_ADMINS) { ?>
                        <th id="th8">{{traducirFrase("Activo")}}</th>
                    <?php } ?>
                    <?php if ($_SESSION["Grupo"] == GRUPO_SUPERVISORES) { ?>
                        <th id="th8">{{traducirFrase("Activo")}}</th>
                    <?php } ?>
                </tr>
            </thead>
            <tbody>
                <tr v-for="dato in d.Campanas">
                    <td>{{dato.id}}</td>
                    <td>{{dato.nombre}}</td>
                    <td>{{dato.grupo}}</td>
                    <td v-if="dato.metodo==='MANUAL'">{{traducirFrase("SALIENTE - MANUAL")}}</td>
                    <td v-else-if="dato.metodo==='RATIO'">{{traducirFrase("PROGRESIVO")}}</td>
                    <td v-else-if="dato.metodo==='ADAPT_AVERAGE'">{{traducirFrase("PREDICTIVO PROMEDIO")}}</td>
                    <td v-else-if="dato.metodo==='ADAPT_HARD_LIMIT'">{{traducirFrase("PREDICTIVO ESTRICTO")}}</td>
                    <td v-else-if="dato.metodo==='ADAPT_TAPERED'">{{traducirFrase("PREDICTIVO TAPERED")}}</td>
                    <td v-else-if="dato.metodo==='INBOUND_MAN' && dato.tieneAutopausa">{{traducirFrase("ENTRADA - ASISTIDO")}}</td>
                    <td v-else-if="dato.metodo==='INBOUND_MAN'">{{traducirFrase("ENTRADA - MANUAL")}}</td>
                    <td v-else>{{dato.metodo}}</td>
                    <td>{{dato.nivel}}</td>
                    <td>{{dato.orden}}</td>
                    <td>
                        <?php if ($_SESSION["Grupo"] == GRUPO_ADMINS) { ?>
                            <a href="#" class="tooltipped" v-bind:data-tooltip="translate('Editar campaña')" data-position="top" v-on:click="abreModal2(dato.id,dato.idcampaign_wa)"><i class="material-icons">edit</i></a>
                            <a href="#" class="tooltipped" v-bind:data-tooltip="translate('Borrar campaña')" data-position="top" v-on:click="deleteCampana(dato.nombre,dato.id)"><i class="material-icons">delete</i></a>
                            <a href="#" class="tooltipped" v-bind:data-tooltip="translate('Duplicar campaña')" data-position="top" v-on:click="duplicarCampana(dato.nombre,dato.id)"><i class="material-icons">content_copy</i></a>
                        <?php } ?>
                        <a class="tooltipped" v-bind:data-tooltip="translate('Estados de calificación')" data-position="top" href="#" v-on:click="abreModal3(dato.nombre,dato.id)"><i class="material-icons ">phone_missed</i></a>
                        <?php if ($_SESSION["Grupo"] == GRUPO_ADMINS) { ?>
                            <a class="tooltipped" v-if="dato.campaign_allow_inbound == 'Y'" :data-tooltip="traducirFrase('Grupos de entrada')" data-position="top" href="#" @click="$emit('ingroups',dato)"><i class="material-icons ">play_for_work</i></a>
                            <!--  -->
                            <a class="tooltipped" :data-tooltip="traducirFrase('Agentes de la campaña')" data-position="top" href="#" @click="$emit('users',dato)"><i class="material-icons ">assignment_ind</i></a>
                            <!--  -->
                            <a class="tooltipped" :data-tooltip="traducirFrase('Grupos de transferencias')" data-position="top" href="#" @click="$emit('xfers',dato)"><i class="material-icons ">group_work</i></a>
                            <!--  -->
                            <?php if (isset($_SESSION["allowEncuestas"]) && $_SESSION["allowEncuestas"] == 1) { ?>
                                <a class="tooltipped" :data-tooltip="traducirFrase('Encuestas')" data-position="top" href="#" @click="$emit('polls',dato)"><i class="material-icons ">poll</i></a>
                            <?php } ?>
                        <?php } ?>
                        <a class="tooltipped" :data-tooltip="traducirFrase('Estatus de reciclaje')" data-position="top" href="#" v-on:click="abreModal4(dato.nombre,dato.id)"><i class="material-icons ">autorenew</i></a>
                        <a class="tooltipped" v-bind:data-tooltip="translate('Codigos de Pausa')" data-position="top" href="#" v-on:click="abreModalPausa(dato.id)"><i href="#" class="material-icons">phone_paused</i></a>
                        <a class="tooltipped" :data-tooltip="translate('Ventanas de Agente')" data-position="top" href="#" @click="abrirModalFrames(dato)"><i href="#" class="material-icons">tab</i></a>
                        <!-- <a class="tooltipped" :data-tooltip="translate('Configurar pausado automático')" data-position="top" href="#" @click="abrirAutopausa(dato)"><i href="#" class="material-icons">stop</i></a> -->
                        <a href="#" @click.prevent="$emit('dates', dato.id)" class="tooltipped" v-bind:data-tooltip="translate('Descargar campaña')" data-position="top"><i class="material-icons">cloud_download</i></a>
                        <?php if (NEED_WA && $_SESSION['allow_waCli']) { ?>
                            <a href="#" v-if="dato.haveWA==='1'" class="tooltipped modal-trigger" data-target="formuUp" :data-tooltip="traducirFrase('Subir registro a campaña (WhatsApp)')" data-position="top" v-bind:onclick="'idCampanaWAW=\`'+dato.idWA+'\`;'"><i class="material-icons">message</i></a>
                            <a href="#" v-if="dato.haveWA==='1'" class="tooltipped modal-trigger" data-target="formuCRM" :data-tooltip="traducirFrase('Mascara de datos (WhatsApp)')" data-position="top" v-bind:onclick="'idCampanaWAW=\`'+dato.idWA+'\`;'"><i class="material-icons">file_upload</i></a>
                            <a v-if="dato.haveWA==='1'" :href="'campanas/downloadCSVWhatsApp?campana='+dato.idWA" class="tooltipped" v-bind:data-tooltip="translate('Descargar reporte de mensajes enviados (WhatsApp)')" data-position="top"><i class="material-icons">cloud_download</i></a>
                            <a v-if="dato.haveWA==='1'" :href="'campanas/downloadFileWhatsApp?campana='+dato.idWA" class="tooltipped" v-bind:data-tooltip="translate('Descargar reporte de archivos (WhatsApp)')" data-position="top"><i class="material-icons">file_download</i></a>
                        <?php } ?>


                    </td>
                    <?php if ($_SESSION["Grupo"] == GRUPO_ADMINS) { ?>
                        <td>
                            <div class="switch">
                                <label class="active">
                                    Off
                                    <input type="checkbox" class="" v-on:click="activaCampana(dato.id)" :checked="dato.activo == 'Y'">
                                    <span id="switch" class="lever  "></span>
                                    On
                                </label>
                            </div>
                        </td>
                    <?php } ?>

                    <?php if ($_SESSION["Grupo"] == GRUPO_SUPERVISORES) { ?>
                        <td>
                            <div class="switch">
                                <label class="active">
                                    Off
                                    <input disabled type="checkbox" class="" v-on:click="activaCampana(dato.id)" :checked="dato.activo == 'Y'">
                                    <span id="switch" class="lever  "></span>
                                    On
                                </label>
                            </div>
                        </td>
                    <?php } ?>

                </tr>
            </tbody>
        </table>
        <div id="barrita">
            <center><img src="<?= IMG_ADMIN; ?>spinner.gif"></center>
        </div>
        <br>
        <?php if ($_SESSION["Grupo"] == GRUPO_ADMINS) { ?>
            <div class="center" id="botonCrear">
                <a class="waves-effect waves-light btn blue lighten-2 " href="javascript:abreModal()" id="Nueva Campaña">{{traducirFrase("Nueva campaña")}}</a>
            </div>
        <?php } ?>
        <center><img src="<?= IMG_ADMIN; ?>spinner.gif" width="60" height="60" style="display: none; margin-top: 2rem;" id="spinnerPagination"></center>
        <ul class="pagination center" id='paginacion'>

        </ul>
    </div>
</div>
